searchData={"content_type":"text/markdown","items":[{"doc":"A GenStage Producer for Redis Stream.\n\nBroadway producer acts as a consumer in the specified Redis stream\nconsumer group. You can run multiple consumers to get better\nthroughput and fault tolerance. Please check [Redis Stream\nIntro](https://redis.io/topics/streams-intro) for details on stream\ndata type.\n\nIt supports failover by automatically claiming pending messages when\na node dies. A node is considered dead when it fails to send\nheartbeats.\n\nCurrently, it only supports Redis 6.0.2 and above","ref":"OffBroadwayRedisStream.Producer.html","title":"OffBroadwayRedisStream.Producer","type":"module"},{"doc":"* `:redis_client_opts` - Required. Redis client specific options. Default client is [Redix](https://hexdocs.pm/redix/Redix.html) and for Redix this is used to start redix process `Redix.start_link(opts)`. see [Redix Documentation](https://hexdocs.pm/redix/Redix.html#start_link/1)\n\n  * `:receive_interval` - Optional. The duration (in milliseconds) for which the producer\n    waits before making a request for more messages if there are no events in stream. Default is `1000`.\n\n  * `:stream` - Required. Redis stream name\n\n  * `:group` - Required. Redis consumer group. Group will be created with `:group_start_id` ID if it is not already present.\n\n  * `:group_start_id` - Optional. Starting stream ID which should be used when consumer group *created*. Use $ for latest ID. see [XGROUP CREATE](https://redis.io/commands/xgroup). Default is `$`\n\n  * `:consumer_name` - Required. Redis consumer name for the Broadway instance in the consumer-group. If you are running multiple consumers, make sure that each consumer has unique name.\n\n  * `:heartbeat_interval` - Optional. Producer sends heartbeats at regular intervals, this is interval duration. Default is `5000`\n\n  * `:allowed_missed_heartbeats` - Optional. Number of allowed missing heartbeats for a consumer. The consumer is considered to be dead after this and other consumers claim its pending messages. Default is `3`\n\n  * `:make_stream` - Optional. Appends MKSTREAM subcommand to `XGROUP CREATE` which automatically create the stream if it doesn't exist. See [XGROUP CREATE](https://redis.io/commands/xgroup). Default is `false`\n\n  * `delete_on_acknowledgment` - Optional. When `XACK`ing a message also\n    `XDEL`ete it. Defaults to `false`","ref":"OffBroadwayRedisStream.Producer.html#module-producer-options","title":"Producer Options - OffBroadwayRedisStream.Producer","type":"module"},{"doc":"Both successful and failed messages are acknowledged by default. Use\n`Broadway.Message.configure_ack/2` to change this behaviour for\nfailed messages. If a message configured to retry, that message will\nbe attempted again in next batch.\n\n```elixir\nif message.metadata.attempt < @max_attempts do\n  Message.configure_ack(message, retry: true)\nelse\n  message\nend\n```\n\n`attempt` field in metadata can be used to control maximum retries.\nuse `handle_failure` callback to handle failures by moving messages\nto other stream or persisting failed jobs etc","ref":"OffBroadwayRedisStream.Producer.html#module-acknowledgements","title":"Acknowledgements - OffBroadwayRedisStream.Producer","type":"module"},{"doc":"Message data is a 2 element list. First item is id of the message,\nsecond is the data","ref":"OffBroadwayRedisStream.Producer.html#module-message-data","title":"Message Data - OffBroadwayRedisStream.Producer","type":"module"},{"doc":"If `message.metadata.retry_after` is present and represents a unix\ntimestamp (in milliseconds) in the future then the message will not\nbe retried until after the time has passed. This is useful for when\nyou are using `off_broadway_redis_stream` to talk to third party\napis that may rate limit you and you need to back off from sending\nrequests.","ref":"OffBroadwayRedisStream.Producer.html#module-retry-after","title":"Retry After - OffBroadwayRedisStream.Producer","type":"module"},{"doc":"# OffBroadwayRedisStream\n\n[![CI](https://github.com/akash-akya/off_broadway_redis_stream/actions/workflows/elixir.yml/badge.svg)](https://github.com/akash-akya/off_broadway_redis_stream/actions/workflows/elixir.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/off_broadway_redis_stream.svg)](https://hex.pm/packages/off_broadway_redis_stream)\n[![docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/off_broadway_redis_stream/)\n\nA Redis Stream consumer for [Broadway](https://github.com/dashbitco/broadway).\n\nBroadway producer acts as a consumer in the specified Redis stream consumer group. You can run multiple consumers to get better throughput and fault tolerance. Please check [Redis Stream Intro](https://redis.io/topics/streams-intro) for details on stream data type.\n\nIt supports failover by automatically claiming pending messages when a node dies. A node is considered dead when it fails to send heartbeats.\n\n```elixir\ndefmodule MyBroadway do\n  use Broadway\n\n  def start_link(_opts) do\n    Broadway.start_link(__MODULE__,\n      name: __MODULE__,\n      producer: [\n        module:\n          {OffBroadwayRedisStream.Producer,\n           [\n             redis_client_opts: [host: \"localhost\"],\n             stream: \"orders\",\n             group: \"processor-group\",\n             consumer_name: hostname()\n           ]}\n      ],\n      processors: [\n        default: [min_demand: 5, max_demand: 1000]\n      ]\n    )\n  end\n\n  def handle_message(_, message, _) do\n    [_id, key_value_list] = message.data\n    IO.inspect(key_value_list, label: \"Got message\")\n    message\n  end\n\n  @max_attempts 5\n\n  def handle_failed(messages, _) do\n    for message <- messages do\n      if message.metadata.attempt < @max_attempts do\n        Broadway.Message.configure_ack(message, retry: true)\n      else\n        [id, _] = message.data\n        IO.inspect(id, label: \"Dropping\")\n      end\n    end\n  end\n\n  defp hostname do\n    {:ok, host} = :inet.gethostname()\n    to_string(host)\n  end\nend\n```\n\nCurrently, it only supports Redis 6.0.2 and above.","ref":"readme.html","title":"OffBroadwayRedisStream","type":"extras"},{"doc":"```elixir\ndef deps do\n  [\n    {:off_broadway_redis_stream, \"~> x.x.x\"}\n  ]\nend\n```\n\n#","ref":"readme.html#installation","title":"Installation - OffBroadwayRedisStream","type":"extras"},{"doc":"Copyright (c) 2021 Akash Hiremath.\n\nOffBroadwayRedisStream source code is released under Apache License 2.0. Check [LICENSE](LICENSE.md) for more information.","ref":"readme.html#license","title":"License - OffBroadwayRedisStream","type":"extras"},{"doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS","ref":"license.html","title":"LICENSE","type":"extras"}]}